@@ -1,5 +1,4 @@
 use crate::paths;
-use pretty_assertions::assert_eq;
 use std::{
     fmt,
     fs::{create_dir_all, File},
@@ -89,13 +88,8 @@ impl NormalizedOutput {
         eprintln!("Comparing output to {}", path.display());
         create_dir_all(path.parent().unwrap()).expect("failed to run `mkdir -p`");
 
-        let diff = Diff {
-            expected,
-            actual: self,
-        };
         if std::env::var("UPDATE").unwrap_or(String::from("0")) == "1" {
-            // ::write_to_file(&path_for_actual, &self.0);
-            crate::write_to_file(&path, &diff.actual.0);
+            crate::write_to_file(&path, &self.0);
 
             eprintln!(
                 "Assertion failed: \nActual file printed to {}",
@@ -103,7 +97,16 @@ impl NormalizedOutput {
             );
         }
 
-        assert_eq!(diff.expected, diff.actual, "Actual:\n{}", diff.actual);
+        if self.0.lines().count() <= 5 {
+            assert_eq!(expected, self, "Actual:\n{}", self);
+        }
+
+        let diff = Diff {
+            expected,
+            actual: self,
+        };
+
+        pretty_assertions::assert_eq!(diff.expected, diff.actual, "Actual:\n{}", diff.actual);
 
         // Actually unreachable.
         Err(diff)
